@@ -1,4 +1,6 @@
-/* GDM - The GNOME Display Manager
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
+ * GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,37 +20,127 @@
 
 #include "config.h"
 
-#include <glib/gi18n.h>
-#include <syslog.h>
 #include <signal.h>
+#include <string.h>
 #include <sys/wait.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <errno.h>
 
+#ifdef HAVE_SMF_CONTRACTS
+#include <sys/ctfs.h>
+#include <sys/contract.h>
+#include <sys/contract/process.h>
+#include <libcontract.h>
+#endif
+
+#include <glib/gi18n.h>
+
 #include "gdm.h"
 #include "gdm-net.h"
 #include "server.h"
 #include "display.h"
 #include "slave.h"
 #include "misc.h"
-#include "xdmcp.h"
 #include "choose.h"
 #include "auth.h"
 #include "gdm-net.h"
-#include "gdmconfig.h"
+
+#include "gdm-common.h"
+#include "gdm-log.h"
+#include "gdm-daemon-config.h"
 
 /* External vars */
-extern gint xdmcp_sessions;
-extern gint flexi_servers;
-extern gint xdmcp_pending;
-extern gboolean gdm_in_final_cleanup;
-extern GSList *displays;
 extern GdmConnection *fifoconn;
 extern GdmConnection *pipeconn;
 extern GdmConnection *unixconn;
 extern int slave_fifo_pipe_fd; /* the slavepipe (like fifo) connection, this is the write end */
+extern gint flexi_servers;
+
+/**
+ * gdm_display_alloc:
+ * @id: Local display number
+ * @command: Command line for starting the X server
+ *
+ * Allocate display structure for a local X server
+ */
+
+GdmDisplay *
+gdm_display_alloc (gint id, const gchar *command, const gchar *device)
+{
+    gchar hostname[1024];
+    GdmDisplay *d;
+
+    hostname[1023] = '\0';
+    if (gethostname (hostname, 1023) == -1)
+            strcpy (hostname, "localhost.localdomain");
+
+    d = g_new0 (GdmDisplay, 1);
+
+    d->logout_action = GDM_LOGOUT_ACTION_NONE;
+    d->authfile = NULL;
+    d->authfile_gdm = NULL;
+    d->auths = NULL;
+    d->userauth = NULL;
+    d->command = g_strdup (command);
+    d->cookie = NULL;
+    d->dispstat = DISPLAY_UNBORN;
+    d->greetpid = 0;
+    d->name = g_strdup_printf (":%d", id);
+    d->hostname = g_strdup (hostname);
+    d->windowpath = NULL;
+    /* Not really used for not XDMCP */
+    memset (&(d->addr), 0, sizeof (d->addr));
+    d->dispnum = id;
+    d->servpid = 0;
+    d->servstat = SERVER_DEAD;
+    d->sesspid = 0;
+    d->slavepid = 0;
+    d->type = TYPE_STATIC;
+    d->attached = TRUE;
+    d->sessionid = 0;
+    d->acctime = 0;
+    d->dsp = NULL;
+    d->screenx = 0; /* xinerama offset */
+    d->screeny = 0;
+
+    d->handled = TRUE;
+    d->tcp_disallowed = FALSE;
+
+    d->priority = 0;
+    d->vt = -1;
+    d->vtnum = -1;
+    if (device != NULL)
+	d->device_name = g_strdup (device);
+    else
+	d->device_name = NULL;
+
+    d->x_servers_order = -1;
+
+    d->last_loop_start_time = 0;
+    d->last_start_time = 0;
+    d->retry_count = 0;
+    d->sleep_before_run = 0;
+    d->login = NULL;
+    d->preset_user = NULL;
+
+    d->timed_login_ok = FALSE;
+
+    d->slave_notify_fd = -1;
+    d->master_notify_fd = -1;
+
+    d->xsession_errors_bytes = 0;
+    d->xsession_errors_fd = -1;
+    d->session_output_fd = -1;
+
+    d->chooser_output_fd = -1;
+    d->chooser_last_line = NULL;
+
+    d->theme_name = NULL;
+
+    return d;
+}
 
 static gboolean
 gdm_display_check_loop (GdmDisplay *disp)
@@ -201,7 +293,7 @@ wait_again:
 		    /* rekill the slave to tell it to
 		       hurry up and die if we're getting
 		       killed ourselves */
-		    if ((gdm_signal_terminthup_was_notified ()) ||
+		    if ((gdm_daemon_config_signal_terminthup_was_notified ()) ||
 			(t + 10 <= time (NULL))) {
 			    gdm_debug ("whack_old_slave: GOT ANOTHER SIGTERM (or it was 10 secs already), killing slave again with SIGKILL");
 			    t = time (NULL);
@@ -233,6 +325,140 @@ wait_again:
     d->slavepid = 0;
 }
 
+#ifdef HAVE_SMF_CONTRACTS
+static int contracts_fd = -1;
+
+void
+contracts_pre_fork ()
+{
+   const char *errmsg = "opening process contract template";
+
+	/*
+	 * On failure, just continue since it is better to start with
+	 * children in the same contract than to not start them at all.
+	 */
+	if (contracts_fd == -1) {
+		if ((contracts_fd = open64 (CTFS_ROOT "/process/template",
+					    O_RDWR)) == -1)
+			goto exit;
+
+		errmsg = "setting contract terms";
+		if ((errno = ct_pr_tmpl_set_param (contracts_fd, CT_PR_PGRPONLY)))
+			goto exit;
+
+		if ((errno = ct_tmpl_set_informative (contracts_fd, CT_PR_EV_HWERR)))
+			goto exit;
+
+		if ((errno = ct_pr_tmpl_set_fatal (contracts_fd, CT_PR_EV_HWERR)))
+			goto exit;
+
+		if ((errno = ct_tmpl_set_critical (contracts_fd, 0)))
+			goto exit;
+	}
+
+	errmsg = "setting active template";
+	if ((errno = ct_tmpl_activate (contracts_fd)))
+		goto exit;
+
+	gdm_debug ("Set active contract");
+	return;
+
+exit:
+	if (contracts_fd != -1)
+		(void) close (contracts_fd);
+
+	contracts_fd = -1;
+
+	if (errno) {
+		gdm_debug (
+			"Error setting up active contract template: %s while %s",
+			strerror (errno), errmsg);
+	}
+}
+
+void
+contracts_post_fork_child ()
+{
+	/* Clear active template so no new contracts are created on fork */
+	if (contracts_fd == -1)
+		return;
+
+	if ((errno = (ct_tmpl_clear (contracts_fd)))) {
+		gdm_debug (
+			"Error clearing active contract template (child): %s",
+			strerror (errno));
+	} else {
+		gdm_debug ("Cleared active contract template (child)");
+	}
+
+	(void) close (contracts_fd);
+
+	contracts_fd = -1;
+}
+
+void
+contracts_post_fork_parent (int fork_succeeded)
+{
+	char path[PATH_MAX];
+	int cfd;
+	ct_stathdl_t status;
+	ctid_t latest;
+
+	/* Clear active template, abandon latest contract. */
+	if (contracts_fd == -1)
+		return;
+
+	if ((errno = ct_tmpl_clear (contracts_fd)))
+		gdm_debug ("Error while clearing active contract template: %s",
+			   strerror (errno));
+	else
+		gdm_debug ("Cleared active contract template (parent)");
+
+	if (!fork_succeeded)
+		return;
+
+	if ((cfd = open64 (CTFS_ROOT "/process/latest", O_RDONLY)) == -1) {
+		gdm_debug ("Error getting latest contract: %s",
+			   strerror(errno));
+		return;
+	}
+
+	if ((errno = ct_status_read (cfd, CTD_COMMON, &status)) != 0) {
+		gdm_debug ("Error getting latest contract ID: %s",
+			   strerror(errno));
+		(void) close (cfd);
+		return;
+	}
+
+	latest = ct_status_get_id (status);
+	ct_status_free (status);
+	(void) close (cfd);
+
+
+	if ((snprintf (path, PATH_MAX, CTFS_ROOT "/all/%ld/ctl", latest)) >=
+	     PATH_MAX) {
+		gdm_debug ("Error opening the latest contract ctl file: %s",
+			   strerror (ENAMETOOLONG));
+		return;
+	}
+
+	cfd = open64 (path, O_WRONLY);
+	if (cfd == -1) {
+		gdm_debug ("Error opening the latest contract ctl file: %s",
+			   strerror (errno));
+		return;
+	}
+ 
+	if ((errno = ct_ctl_abandon (cfd)))
+		gdm_debug ("Error abandoning latest contract: %s",
+			   strerror (errno));
+	else
+		gdm_debug ("Abandoned latest contract");
+
+	(void) close (cfd);
+}
+#endif HAVE_SMF_CONTRACTS
+
 /**
  * gdm_display_manage:
  * @d: Pointer to a GdmDisplay struct
@@ -272,12 +498,22 @@ gdm_display_manage (GdmDisplay *d)
 
     d->managetime = time (NULL);
 
+    gdm_debug ("Forking slave process");
+
+#ifdef HAVE_SMF_CONTRACTS
+    contracts_pre_fork ();
+#endif
+
     /* Fork slave process */
     pid = d->slavepid = fork ();
 
     switch (pid) {
 
     case 0:
+#ifdef HAVE_SMF_CONTRACTS
+        contracts_post_fork_child ();
+#endif
+
 	setpgid (0, 0);
 
 	/* Make the slave it's own leader.  This 1) makes killing -pid of
@@ -291,10 +527,6 @@ gdm_display_manage (GdmDisplay *d)
 
 	d->slavepid = getpid ();
 
-	/* Close XDMCP fd in slave process */
-	if (gdm_get_value_bool (GDM_KEY_XDMCP))
-	    gdm_xdmcp_close ();
-
 	gdm_connection_close (fifoconn);
 	fifoconn = NULL;
 	gdm_connection_close (pipeconn);
@@ -302,7 +534,7 @@ gdm_display_manage (GdmDisplay *d)
 	gdm_connection_close (unixconn);
 	unixconn = NULL;
 
-	closelog ();
+	gdm_log_shutdown ();
 
 	/* Close everything */
 	gdm_close_all_descriptors (0 /* from */, fds[0] /* except */, slave_fifo_pipe_fd /* except2 */);
@@ -313,7 +545,7 @@ gdm_display_manage (GdmDisplay *d)
 	gdm_open_dev_null (O_RDWR); /* open stdout - fd 1 */
 	gdm_open_dev_null (O_RDWR); /* open stderr - fd 2 */
 
-	openlog ("gdm", LOG_PID, LOG_DAEMON);
+	gdm_log_init ();
 
 	d->slave_notify_fd = fds[0];
 
@@ -344,13 +576,17 @@ gdm_display_manage (GdmDisplay *d)
 	break;
     }
 
+#ifdef HAVE_SMF_CONTRACTS
+    contracts_post_fork_parent ((pid > 0));
+#endif
+
     /* invalidate chosen hostname */
     g_free (d->chosen_hostname);
     d->chosen_hostname = NULL;
 
-    /* use_chooser can only be temporary, if you want it permanent you set it up
-       in the server definition with "chooser=true" and it will get set up during
-       server command line resolution */
+    /* use_chooser can only be temporary, if you want it permanent you set it
+       up in the server definition with "chooser=true" and it will get set up
+       during server command line resolution */
     d->use_chooser = FALSE;
 
     if (SERVER_IS_LOCAL (d)) {
@@ -394,6 +630,7 @@ gdm_display_unmanage (GdmDisplay *d)
     gdm_debug ("gdm_display_unmanage: Display stopped");
 }
 
+
 /* Why recount?  It's just a lot more robust this way and
    gets around those nasty one off errors and races.  And we never
    have so many displays that this would get too slow. */
@@ -401,19 +638,15 @@ static void
 count_session_limits (void)
 {
 	GSList *li;
+	GSList *displays;
+
+	displays = gdm_daemon_config_get_display_list ();
 
-	xdmcp_sessions = 0;
-	xdmcp_pending = 0;
 	flexi_servers = 0;
 
 	for (li = displays; li != NULL; li = li->next) {
 		GdmDisplay *d = li->data;
-		if (SERVER_IS_XDMCP (d)) {
-			if (d->dispstat == XDMCP_MANAGED)
-				xdmcp_sessions++;
-			else if (d->dispstat == XDMCP_PENDING)
-				xdmcp_pending++;
-		}
+
 		if (SERVER_IS_FLEXI (d)) {
 			flexi_servers++;
 		}
@@ -430,6 +663,7 @@ count_session_limits (void)
 void
 gdm_display_dispose (GdmDisplay *d)
 {
+
     if (d == NULL)
 	return;
 
@@ -453,7 +687,7 @@ gdm_display_dispose (GdmDisplay *d)
 	    d->master_notify_fd = -1;
     }
 
-    displays = g_slist_remove (displays, d);
+    gdm_daemon_config_display_list_remove (d);
 
     d->dispstat = DISPLAY_DEAD;
     d->type = -1;
@@ -472,6 +706,9 @@ gdm_display_dispose (GdmDisplay *d)
     g_free (d->hostname);
     d->hostname = NULL;
 
+    g_free (d->windowpath);
+    d->windowpath = NULL;
+
     g_free (d->addrs);
     d->addrs = NULL;
     d->addr_count = 0;
@@ -509,9 +746,15 @@ gdm_display_dispose (GdmDisplay *d)
     g_free (d->userauth);
     d->userauth = NULL;
 
+    g_free (d->windowpath);
+    d->windowpath = NULL;
+
     g_free (d->command);
     d->command = NULL;
 
+    g_free (d->device_name);
+    d->device_name = NULL;
+
     g_free (d->cookie);
     d->cookie = NULL;
 
@@ -531,6 +774,9 @@ gdm_display_dispose (GdmDisplay *d)
     g_free (d->login);
     d->login = NULL;
 
+    g_free (d->preset_user);
+    d->preset_user = NULL;
+
     g_free (d->xsession_errors_filename);
     d->xsession_errors_filename = NULL;
 
@@ -555,6 +801,9 @@ gdm_display_dispose (GdmDisplay *d)
     g_free (d->theme_name);
     d->theme_name = NULL;
 
+    g_free (d->xserver_session_args);
+    d->xserver_session_args = NULL;
+
     g_free (d);
 }
 
@@ -570,6 +819,9 @@ GdmDisplay *
 gdm_display_lookup (pid_t pid)
 {
     GSList *li;
+    GSList *displays;
+
+    displays = gdm_daemon_config_get_display_list ();
 
     /* Find slave in display list */
     for (li = displays; li != NULL; li = li->next) {
