@@ -23,12 +23,16 @@
 
 #include <X11/Xlib.h> /* for Display */
 #include <X11/Xmd.h> /* for CARD32 */
+#include <sys/types.h>
+#include <sys/socket.h>
 #include <netinet/in.h> /* for in_addr */
 
 typedef struct _GdmDisplay GdmDisplay;
 
 #include "gdm-net.h" /* for GdmConnection */
 
+#include "gdm.h" /* for GDM_CUSTOM_COMMAND_MAX */
+
 #define TYPE_STATIC 1		/* X server defined in GDM configuration */
 #define TYPE_XDMCP 2		/* Remote display/Xserver */
 #define TYPE_FLEXI 3		/* Local Flexi X server */
@@ -59,7 +63,7 @@ typedef enum {
 	GDM_LOGOUT_ACTION_REBOOT,
 	GDM_LOGOUT_ACTION_SUSPEND,
 	GDM_LOGOUT_ACTION_CUSTOM_CMD_FIRST,
-	GDM_LOGOUT_ACTION_CUSTOM_CMD_LAST,
+	GDM_LOGOUT_ACTION_CUSTOM_CMD_LAST = GDM_LOGOUT_ACTION_CUSTOM_CMD_FIRST + GDM_CUSTOM_COMMAND_MAX - 1,
 	GDM_LOGOUT_ACTION_LAST
 } GdmLogoutAction;
 
@@ -122,6 +126,7 @@ struct _GdmDisplay
 	pid_t slavepid;
 	pid_t greetpid;
 	pid_t sesspid;
+	pid_t fbconsolepid;
 	int last_sess_status; /* status returned by last session */
 
 	/* Notification connection */
@@ -150,10 +155,15 @@ struct _GdmDisplay
 
         gchar *xserver_session_args;
 
+	/*
+	 * The device associated with the display, if specified in the
+	 * configuration file
+	 */
+	gchar *device_name;
+
 	/* Only set in the main daemon as that's the only place that cares */
 	GdmLogoutAction logout_action;
 
-
 	/* XDMCP TYPE */
 
 	time_t acctime;
@@ -171,7 +181,8 @@ struct _GdmDisplay
 
 	/* ALL LOCAL TYPE (static, flexi) */
 
-	int vt;
+	int vt;     /* The VT number used when starting via GDM */
+	int vtnum;  /* The VT number of the display */
 	pid_t servpid;
 	guint8 servstat;
 	gchar *command;
@@ -210,7 +221,7 @@ struct _GdmDisplay
 	char *parent_temp_auth_file;
 };
 
-GdmDisplay *gdm_display_alloc    (gint id, const gchar *command);
+GdmDisplay *gdm_display_alloc    (gint id, const gchar *command, const gchar *device);
 gboolean    gdm_display_manage   (GdmDisplay *d);
 void        gdm_display_dispose  (GdmDisplay *d);
 void        gdm_display_unmanage (GdmDisplay *d);
