@@ -91,7 +91,7 @@ static gboolean did_we_ask_for_password = FALSE;
 static char *selected_user = NULL;
 
 static gboolean opened_session = FALSE;
-static gboolean did_setcred = FALSE;
+static gboolean did_setcred    = FALSE;
 
 extern char *gdm_ack_question_response;
 
@@ -360,17 +360,17 @@ solaris_xserver_cred (char *login, GdmDisplay *d, struct passwd *pwent)
                 displayNumber = atoi (tmp);
 	}
 
-        sprintf (pipe, "%s/%d", SDTLOGIN_DIR, displayNumber);
+        sprintf (pipe, "%s/%d", GDM_SDTLOGIN_DIR, displayNumber);
 
-        if (g_stat (SDTLOGIN_DIR, &statbuf) == 0) {
+        if (g_stat (GDM_SDTLOGIN_DIR, &statbuf) == 0) {
 		if (! statbuf.st_mode & S_IFDIR) {
 			gdm_debug ("solaris_xserver_cred: %s is not a directory\n",
-				   SDTLOGIN_DIR);
+				   GDM_SDTLOGIN_DIR);
 			return;
 		}
 	}
 	else {
-		gdm_debug ("solaris_xserver_cred: %s does not exist\n", SDTLOGIN_DIR);
+		gdm_debug ("solaris_xserver_cred: %s does not exist\n", GDM_SDTLOGIN_DIR);
 		return;
 	}
 
@@ -900,6 +900,7 @@ gdm_verify_user (GdmDisplay *d,
 	gboolean credentials_set = FALSE;
 	gboolean error_msg_given = FALSE;
 	gboolean started_timer   = FALSE;
+	gboolean allow_remote    = TRUE;
 
 #ifdef HAVE_ADT
 	int pw_change = PW_FALSE;   /* if got to trying to change password */
@@ -980,11 +981,9 @@ gdm_verify_user (GdmDisplay *d,
 #endif
 
 	passreq = gdm_read_default ("PASSREQ=");
-	if ((passreq != NULL) &&
-	    g_ascii_strcasecmp (passreq, "YES") == 0)
-		gdm_daemon_config_set_value_bool (GDM_KEY_PASSWORD_REQUIRED, TRUE);
 
-	if (gdm_daemon_config_get_value_bool (GDM_KEY_PASSWORD_REQUIRED))
+	if (gdm_daemon_config_get_value_bool (GDM_KEY_PASSWORD_REQUIRED) ||
+            ((passreq != NULL) && g_ascii_strcasecmp (passreq, "YES") == 0))
 		null_tok |= PAM_DISALLOW_NULL_AUTHTOK;
 
 	gdm_verify_select_user (NULL);
@@ -992,8 +991,6 @@ gdm_verify_user (GdmDisplay *d,
 	/* Start authentication session */
 	did_we_ask_for_password = FALSE;
 	if ((pamerr = pam_authenticate (pamh, null_tok)) != PAM_SUCCESS) {
-		/* Log the failed login attempt */
-		log_to_audit_system(login, d->hostname, d->name, AU_FAILED);
 		if ( ! ve_string_empty (selected_user)) {
 			pam_handle_t *tmp_pamh;
 
@@ -1105,17 +1102,16 @@ gdm_verify_user (GdmDisplay *d,
 
 	/* Check if user is root and is allowed to log in */
 	consoleonly = gdm_read_default ("CONSOLE=");
-	if ((consoleonly != NULL) &&
-	    g_ascii_strcasecmp (consoleonly, "/dev/console") == 0)
-		gdm_daemon_config_set_value_bool (GDM_KEY_ALLOW_REMOTE_ROOT, FALSE);
+	if (( ! gdm_daemon_config_get_value_bool (GDM_KEY_ALLOW_REMOTE_ROOT)) ||
+            ((consoleonly != NULL) &&
+	     (g_ascii_strcasecmp (consoleonly, "/dev/console") == 0))) {
+		allow_remote = FALSE;
+	}
 
 	pwent = getpwnam (login);
 	if (( ! gdm_daemon_config_get_value_bool (GDM_KEY_ALLOW_ROOT) ||
-	    ( ! gdm_daemon_config_get_value_bool (GDM_KEY_ALLOW_REMOTE_ROOT) &&
-	      ! d->attached)) && pwent != NULL && pwent->pw_uid == 0) {
-
-		/* Log the failed login attempt */
-		log_to_audit_system(login, d->hostname, d->name, AU_FAILED);
+            ( ! d->attached && allow_remote == FALSE)) &&
+            (pwent != NULL && pwent->pw_uid == 0)) {
 		gdm_error (_("Root login disallowed on display '%s'"),
 			   d->name);
 		gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
@@ -1149,8 +1145,6 @@ gdm_verify_user (GdmDisplay *d,
 		break;
 	case PAM_NEW_AUTHTOK_REQD :
 		if ((pamerr = pam_chauthtok (pamh, PAM_CHANGE_EXPIRED_AUTHTOK)) != PAM_SUCCESS) {
-			/* Log the failed login attempt */
-			log_to_audit_system(login, d->hostname, d->name, AU_FAILED);
 			gdm_error (_("Authentication token change failed for user %s"), login);
 			gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
 						      _("\nThe change of the authentication token failed. "
@@ -1168,24 +1162,18 @@ gdm_verify_user (GdmDisplay *d,
 #endif	/* HAVE_ADT */
 		break;
 	case PAM_ACCT_EXPIRED :
-		/* Log the failed login attempt */
-		log_to_audit_system(login, d->hostname, d->name, AU_FAILED);
 		gdm_error (_("User %s no longer permitted to access the system"), login);
 		gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
 					      _("\nThe system administrator has disabled your account."));
 		error_msg_given = TRUE;
 		goto pamerr;
 	case PAM_PERM_DENIED :
-		/* Log the failed login attempt */
-		log_to_audit_system(login, d->hostname, d->name, AU_FAILED);
 		gdm_error (_("User %s not permitted to gain access at this time"), login);
 		gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
 					      _("\nThe system administrator has disabled access to the system temporarily."));
 		error_msg_given = TRUE;
 		goto pamerr;
 	default :
-		/* Log the failed login attempt */
-		log_to_audit_system(login, d->hostname, d->name, AU_FAILED);
 		if (gdm_slave_action_pending ())
 			gdm_error (_("Couldn't set acct. mgmt for %s"), login);
 		goto pamerr;
@@ -1237,8 +1225,6 @@ gdm_verify_user (GdmDisplay *d,
 			gdm_error (_("Couldn't open session for %s"), login);
 		goto pamerr;
 	}
-	/* Login succeeded */
-	log_to_audit_system(login, d->hostname, d->name, AU_SUCCESS);
 
 	/* Workaround to avoid gdm messages being logged as PAM_pwdb */
 	gdm_log_shutdown ();
@@ -1269,13 +1255,38 @@ gdm_verify_user (GdmDisplay *d,
 	audit_success_login (pw_change, pwent);
 #endif  /* HAVE_ADT */
 
+	/*
+	 * Login succeeded.
+	 * This function is a no-op if libaudit is not present.
+	 */
+	log_to_audit_system(login, d->hostname, d->name, AU_SUCCESS);
+
 	return login;
 
  pamerr:
+	/*
+	 * Take care of situation where we get here before setting pwent.
+	 * Since login can be passed in as NULL, get the actual value if
+	 * possible.
+	 */
+	if ((pam_get_item (pamh, PAM_USER, &p)) == PAM_SUCCESS) {
+		g_free (login);
+		login = g_strdup ((const char *)p);
+	}
+	if (pwent == NULL && login != NULL) {
+		pwent = getpwnam (login);
+	}
+
 #ifdef  HAVE_ADT
 	audit_fail_login (d, pw_change, pwent, pamerr);
 #endif	/* HAVE_ADT */
 
+	/*
+	 * Log the failed login attempt.
+	 * This function is a no-op if libaudit is not present.
+	 */
+	log_to_audit_system(login, d->hostname, d->name, AU_FAILED);
+
 	/* The verbose authentication is turned on, output the error
 	 * message from the PAM subsystem */
 	if ( ! error_msg_given &&
@@ -1418,11 +1429,9 @@ gdm_verify_setup_user (GdmDisplay *d, const gchar *login, char **new_login)
 	g_free (pam_service_name);
 
 	passreq = gdm_read_default ("PASSREQ=");
-	if ((passreq != NULL) &&
-	    g_ascii_strcasecmp (passreq, "YES") == 0)
-		gdm_daemon_config_set_value_bool (GDM_KEY_PASSWORD_REQUIRED, TRUE);
 
-	if (gdm_daemon_config_get_value_bool (GDM_KEY_PASSWORD_REQUIRED))
+	if (gdm_daemon_config_get_value_bool (GDM_KEY_PASSWORD_REQUIRED) ||
+            ((passreq != NULL) && g_ascii_strcasecmp (passreq, "YES") == 0))
 		null_tok |= PAM_DISALLOW_NULL_AUTHTOK;
 
 	/* Start authentication session */
@@ -1454,11 +1463,6 @@ gdm_verify_setup_user (GdmDisplay *d, const gchar *login, char **new_login)
 		*new_login = g_strdup (after_login);
 	}
 
-#ifdef  HAVE_ADT
-	/* to set up for same auditing calls as in gdm_verify_user */
-	pwent = getpwnam (login);
-#endif	/* HAVE_ADT */
-
 	/* Check if the user's account is healthy. */
 	pamerr = pam_acct_mgmt (pamh, null_tok);
 	switch (pamerr) {
@@ -1585,14 +1589,33 @@ gdm_verify_setup_user (GdmDisplay *d, const gchar *login, char **new_login)
 	audit_success_login (pw_change, pwent);
 #endif	/* HAVE_ADT */
 
+	/*
+	 * Login succeeded.
+	 * This function is a no-op if libaudit is not present
+	 */
+	log_to_audit_system(login, d->hostname, d->name, AU_SUCCESS);
+
 	return TRUE;
 
  setup_pamerr:
+	/*
+	 * Take care of situation where we get here before setting pwent.
+	 * Note login is never NULL when this function is called.
+	 */
+	if (pwent == NULL) {
+		pwent = getpwnam (login);
+	}
 
 #ifdef  HAVE_ADT
 	audit_fail_login (d, pw_change, pwent, pamerr);
 #endif	/* HAVE_ADT */
 
+	/*
+	 * Log the failed login attempt.
+	 * This function is a no-op if libaudit is not present
+	 */
+	log_to_audit_system(login, d->hostname, d->name, AU_FAILED);
+
 	did_setcred = FALSE;
 	opened_session = FALSE;
 	if (pamh != NULL) {
