@@ -229,7 +229,7 @@ process_operation (guchar       op_code,
     gint lookup_status = SESSION_LOOKUP_SUCCESS;
     gchar *firstmsg = NULL;
     gchar *secondmsg = NULL;
-    gint save_session = GTK_RESPONSE_NO;
+    gint dont_save_session = GTK_RESPONSE_YES;
 
     /* Parse opcode */
     switch (op_code) {
@@ -332,16 +332,16 @@ process_operation (guchar       op_code,
 		case SESSION_LOOKUP_PREFERRED_MISSING:
 			firstmsg = g_strdup_printf (_("Do you wish to make %s the default for "
 						      "future sessions?"),
-						    gdm_session_name (tmp));	    
+						      gdm_session_name (gdm_get_default_session ()));
 			secondmsg = g_strdup_printf (_("Your preferred session type %s is not "
 						       "installed on this computer."),
-						     gdm_session_name (gdm_get_default_session ()));
-			save_session = gdm_wm_query_dialog (firstmsg, secondmsg,
-							    _("Make _Default"), _("Just _Log In"), TRUE);
-			
+						       gdm_session_name (tmp));	    
+			dont_save_session = gdm_wm_query_dialog (firstmsg, secondmsg,
+					_("Just _Log In"), _("Make _Default"), TRUE);
+
 			g_free (firstmsg);
 			g_free (secondmsg);
-			gdm_set_save_session (save_session);
+			gdm_set_save_session (dont_save_session);
 			break;
 			
 		case SESSION_LOOKUP_DEFAULT_MISMATCH:
@@ -353,12 +353,12 @@ process_operation (guchar       op_code,
 						       "setting is %s."),
 						     gdm_session_name (session),
 						     gdm_session_name (tmp));
-			save_session = gdm_wm_query_dialog (firstmsg, secondmsg,
-							    _("Make _Default"), _("Just For _This Session"), TRUE);
+			dont_save_session = gdm_wm_query_dialog (firstmsg, secondmsg,
+							    _("Just For _This Session"), _("Make _Default"), TRUE);
 			
 			g_free (firstmsg);
 			g_free (secondmsg);
-			gdm_set_save_session (save_session);
+			gdm_set_save_session (dont_save_session);
 			break;
 		case SESSION_LOOKUP_USE_SWITCHDESK:
 			firstmsg = g_strdup_printf (_("You have chosen %s for this "
@@ -396,7 +396,7 @@ process_operation (guchar       op_code,
 	break;
 
     case GDM_SSESS:
-	if (gdm_get_save_session () == GTK_RESPONSE_YES)
+	if (gdm_get_save_session () == GTK_RESPONSE_NO)
 	  printf ("%cY\n", STX);
 	else
 	  printf ("%c\n", STX);
@@ -569,6 +569,8 @@ process_operation (guchar       op_code,
 	gdm_wm_save_wm_order ();
 
 	gdk_flush ();
+	printf ("%c\n", STX);
+	fflush (stdout);
 
 	_exit (EXIT_SUCCESS);
 
@@ -590,10 +592,16 @@ process_operation (guchar       op_code,
 static gboolean
 key_press_event (GtkWidget *widget, GdkEventKey *key, gpointer data)
 {
-  if (DOING_GDM_DEVELOPMENT && (key->keyval == GDK_Escape))
+  if (key->keyval == GDK_Escape)
     {
-      process_operation (GDM_QUIT, NULL);
-      
+      if (DOING_GDM_DEVELOPMENT)
+        process_operation (GDM_QUIT, NULL);
+      else
+      {
+        printf ("%c%c%c\n", STX, BEL, GDM_INTERRUPT_CANCEL);
+        fflush (stdout);
+      }
+
       return TRUE;
     }
   
@@ -1353,11 +1361,9 @@ main (int argc, char *argv[])
   
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
-  if G_UNLIKELY (DOING_GDM_DEVELOPMENT) {
-     g_signal_connect (G_OBJECT (window), "key_press_event",
-		       G_CALLBACK (key_press_event), NULL);
-  }
-  
+  g_signal_connect (G_OBJECT (window), "key_press_event",
+                    G_CALLBACK (key_press_event), NULL);
+
   canvas = gnome_canvas_new_aa ();
   GTK_WIDGET_UNSET_FLAGS (canvas, GTK_CAN_FOCUS);
   gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas),
