@@ -1,7 +1,7 @@
 /* GDM - The Gnome Display Manager
  * Copyright (C) 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
- * This file Copyright (c) 2003 Sun Microsystems Inc.
+ * This file Copyright (c) 2003-2007 Sun Microsystems, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -431,7 +431,6 @@ leave_enter_emission_hook (GSignalInvocationHint        *ihint,
 {
 	GObject *object;
 	GtkWidget *widget;
-	GtkWindow *window;
 	GdkEventCrossing *event;
 	GdkRectangle rect;
 	GSList *li;
@@ -441,7 +440,6 @@ leave_enter_emission_hook (GSignalInvocationHint        *ihint,
 	object = g_value_get_object (param_values + 0);
 	event  = g_value_get_boxed (param_values + 1);
 	widget = GTK_WIDGET (object);
-	window = GTK_WINDOW (object);
 
 	if (event->detail == GDK_NOTIFY_INFERIOR ||
 	    !GTK_IS_WINDOW (object) || !GTK_WIDGET_TOPLEVEL (object)) {
@@ -556,28 +554,14 @@ leave_enter_emission_hook (GSignalInvocationHint        *ihint,
 
 		for (act_li=curr_binding->actions; act_li != NULL; act_li=act_li->next) {
 			gchar *action = (gchar *)act_li->data;
-#ifdef HAVE_CTRUN
-			gchar *ctrun;
-#endif
 
 			g_return_val_if_fail (action != NULL, TRUE);
 
-#ifdef HAVE_CTRUN
-			ctrun = g_strdup_printf (
-				"/bin/sh -c \"/usr/bin/ctrun -l child -i none %s\"",
-				action);
-			if (!g_shell_parse_argv (ctrun, NULL, &argv, NULL)) {
-				g_free (ctrun);
-				continue;
-			}
-				
-			g_free (ctrun);
-#else
 			if (!g_shell_parse_argv (action, NULL, &argv, NULL))
 				continue;
-#endif
 
-			envp = get_exec_environment (gtk_window_get_screen(window));
+			envp = get_exec_environment (gtk_window_get_screen
+						     (GTK_WINDOW(widget)));
 
 			if (debug_gestures)
 				syslog (LOG_WARNING, "Action is %s", action);
